<?php


//TGMPA required plugin
require_once get_template_directory() . '/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'planet_register_required_plugins' );
function planet_register_required_plugins() {

    $planet_plugins = array(

        //cf7
        array(
            'name'      => esc_html__( 'Contact Form 7', 'eis' ),
            'slug'      => 'contact-form-7',
            'required'  => true,
        ),

        //wp import
        array(
            'name'      => esc_html__( 'Wordpress Importer', 'eis' ),
            'slug'      => 'wordpress-importer',
            'required'  => true,
        ),

        //nd shortcodes
        array(
            'name'      => esc_html__( 'Shortcodes', 'eis' ),
            'slug'      => 'nd-shortcodes',
            'required'  => true,
        ),

        //nd projects
        array(
            'name'      => esc_html__( 'Cost Calculator', 'eis' ),
            'slug'      => 'nd-projects',
            'required'  => true,
        ),

        //woocommerce
        array(
            'name'      => esc_html__( 'WooCommerce', 'eis' ),
            'slug'      => 'woocommerce',
            'required'  => true,
        ),

        //revslider
        array(
            'name'               => esc_html__( 'Revolution Slider', 'eis' ),
            'slug'               => 'revslider', // The plugin slug (typically the folder name).
            'source'             => get_template_directory().'/plugins/revslider.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),
        
        //Visual Composer
        array(
            'name'               => esc_html__( 'Wp Bakery Page Builder', 'eis' ),
            'slug'               => 'js_composer', // The plugin slug (typically the folder name).
            'source'             => get_template_directory().'/plugins/js_composer.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),

    );


    $planet_config = array(
        'id'           => 'eis',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to bundled plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table. 
    );

    tgmpa( $planet_plugins, $planet_config );
}
//END tgmpa


//translation
load_theme_textdomain( 'eis', get_template_directory().'/languages' );


//register my menus
function planet_register_my_menus() {
  register_nav_menu( 'main-menu', esc_html__( 'Main Menu', 'eis' ) );  
}
add_action( 'init', 'planet_register_my_menus' );


//Content_width
if (!isset($content_width )) $content_width  = 1180;


//automatic-feed-links
add_theme_support( 'automatic-feed-links' );

//post-thumbnails
add_theme_support( 'post-thumbnails' );

//post-formats
add_theme_support( 'post-formats', array( 'quote', 'image', 'link', 'video', 'gallery', 'audio' ) );

//title tag
add_theme_support( 'title-tag' );

// Sidebar
function planet_add_sidebars() {

    // Sidebar Main
    register_sidebar(array(
        'name' =>  esc_html__('Sidebar','eis'),
        'id' => 'nicdark_sidebar',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3>',
        'after_title' => '</h3>',
    ));

}
add_action( 'widgets_init', 'planet_add_sidebars' );

//add css and js
function planet_enqueue_scripts()
{
    
    //css
    wp_enqueue_style( 'eis-style', get_stylesheet_uri() );
    wp_enqueue_style( 'eis-fonts', planet_google_fonts_url(), array(), '1.0.0' );

    //comment-reply
    if ( is_singular() ) wp_enqueue_script( 'comment-reply' );

    //navigation
    wp_enqueue_script('planet_navigation', get_template_directory_uri() . '/js/planet_navigation.js', array('jquery'), false, true );

}
add_action('wp_enqueue_scripts', 'planet_enqueue_scripts');

function planet_admin_enqueue_scripts() {
  
  wp_enqueue_style( 'eis-admin-style', get_template_directory_uri() . '/admin-style.css', array(), false, false );
  
}
add_action( 'admin_enqueue_scripts', 'planet_admin_enqueue_scripts' );
//end js


//add custom class to body
function planet_body_class($classes){

    $planet_body_class = 'planet_body';
    $classes[] = esc_attr($planet_body_class);
    return $classes;
    
}
add_filter( 'body_class','planet_body_class' );


//logo settings
add_action('customize_register','planet_customizer_logo');
function planet_customizer_logo( $wp_customize ) {
  

    //Logo
    $wp_customize->add_setting( 'planet_customizer_logo_img', array(
      'type' => 'option', // or 'option'
      'capability' => 'edit_theme_options',
      'theme_supports' => '', // Rarely needed.
      'default' => '',
      'transport' => 'refresh', // or postMessage
      'sanitize_callback' => 'planet_sanitize_callback_logo_img',
    ) );
    $wp_customize->add_control( 
        new WP_Customize_Media_Control( 
            $wp_customize, 
            'planet_customizer_logo_img', 
            array(
              'label' => esc_html__( 'Logo', 'eis' ),
              'section' => 'title_tagline',
              'mime_type' => 'image',
            ) 
        ) 
    );

    //sanitize_callback
    function planet_sanitize_callback_logo_img($planet_logo_img_value) {
        return absint($planet_logo_img_value);
    }


}
//end logo settings

//woocommerce support
add_theme_support( 'woocommerce' );

//define planet theme option
function planet_theme_setup(){
    add_option( 'nicdark_theme_author', 1, '', 'yes' );
    update_option( 'nicdark_theme_author', 1 );
}
add_action( 'after_setup_theme', 'planet_theme_setup' );



//START add google fonts
function planet_google_fonts_url() {
    $planet_font_url = '';
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'eis' ) ) {
        $planet_font_url = add_query_arg( 'family','Open+Sans:400,700|Playfair+Display:400,700', '//fonts.googleapis.com/css' );
    }
    return $planet_font_url;
}
//END add google fonts


//START add placeholder on search widget
function planet_custom_search_form( $planet_search_form ) { 
    
    $planet_search_form = '
    <form role="search" method="get" id="searchform" class="searchform" action="'.home_url('/').'">
        <div>
            <label class="screen-reader-text" for="s">'.esc_html__('Search for', 'eis').' :</label>
            <input type="text" value="'.get_search_query().'" placeholder="'.esc_attr__('Keyword', 'eis').' ..." name="s" id="s">
            <input type="submit" id="searchsubmit" value="'.esc_attr__('Search', 'eis').'">
        </div>
    </form>';
    
    return $planet_search_form;
} 
add_filter( 'get_search_form', 'planet_custom_search_form' );
//END add placeholder on search widget




//START create welcome page on activation

//create transient
add_action( 'after_switch_theme','planet_welcome_set_trans');
function planet_welcome_set_trans(){ if ( ! is_network_admin() ) { set_transient( 'planet_welcome_page_redirect', 1, 30 ); } }

//create page
add_action('admin_menu', 'planet_create_welcome_page');
function planet_create_welcome_page() {
    add_theme_page( esc_html__( 'About', 'eis' ), esc_html__( 'About', 'eis' ),current_user_can( 'edit_theme_options' ),'planet-welcome-theme-page', 'planet_welcome_page_content' );
    remove_submenu_page( 'themes.php', 'planet-welcome-theme-page' );
}

//set redirect
add_action( 'admin_init', 'planet_welcome_theme_page_redirect' );
function planet_welcome_theme_page_redirect() {

    if ( ! get_transient( 'planet_welcome_page_redirect' ) ) { return; }
    delete_transient( 'planet_welcome_page_redirect' );
    if ( is_network_admin() ) { return; }
    wp_safe_redirect( add_query_arg( array( 'page' => 'planet-welcome-theme-page' ), esc_url( admin_url( 'themes.php' ) ) ) );
    exit;

}

//page content
function planet_welcome_page_content(){
    
    $planet_welcome_title = 'Eis';
    $planet_welcome_documentation_link = 'http://documentations.planet-themes.com/eis/';
    $planet_welcome_youtube_video = '#';
    $planet_welcome_color_1 = '#2d2d2d';
    $planet_welcome_color_2 = '#2d2d2d';
    $planet_welcome_theme = 'eis'; //copy and replace all

    echo '

    <style>
        #setting-error-tgmpa { display:none !important; }
    </style>

    <div style="position: relative; margin: 25px 40px 0 20px; max-width: 1050px; font-size: 15px; display: block;">
    
        <div style="float:left; width:100%; padding-right:200px; box-sizing:border-box;">
            <h1 style="margin:0px; margin: .2em 200px 0 0; padding: 0; color: #32373c; line-height: 1.2; font-size: 2.8em; font-weight: 400;">'.esc_html__( 'Welcome to', 'eis' ).' '.$planet_welcome_title.' '.esc_html__( 'Theme', 'eis' ).'</h1>    
            <p style="color:#555d66; font-weight: 400; line-height: 1.6; font-size: 19px;">'.esc_html__( 'Thank you for choosing our theme for the design of your website. In a few simple steps you can import the contents of our demo and start working on your new project.', 'eis' ).'</p>
        </div>

        <img style="position: absolute;right: 0px;width: 110px;top: 20px;" src="'.get_template_directory_uri().'/img/thumbnail.jpg">
        
        <div style="float:left; width:100%;">
            <h3 style="margin-top:30px; margin: 1.25em 0 .6em; font-size: 1.4em; line-height: 1.5;">'.esc_html__( 'Import demo and sample content :', 'eis' ).'</h3>
            <p style="line-height: 1.5; font-size: 16px;">'.esc_html__( 'Follow all steps below to import the contents and the various options of the demo you prefer. Follow the steps carefully and start with your new project !', 'eis' ).'</p>
        </div>

        <div style="float:left; width:100%;">

            <div style="float:left; width:100%;">

                <div style="float:left; width:25%;">
                    <p style="line-height: 1.5; font-size: 16px;"><strong>1 : </strong> <a target="_blank" href="'.admin_url().'themes.php?page=tgmpa-install-plugins">'.esc_html__( 'Install Required Plugins', 'eis' ).'</a></p>
                </div>
                <div style="float:left; width:25%;">
                    <p style="line-height: 1.5; font-size: 16px;"><strong>2 : </strong> '.esc_html__( 'Import Demo Options', 'eis' ).'</p>
                </div>
                <div style="float:left; width:25%;">
                    <p style="line-height: 1.5; font-size: 16px;"><strong>3 : </strong> '.esc_html__( 'Import Content', 'eis' ).'</p>
                </div>
                <div style="float:left; width:25%;">
                    <p style="line-height: 1.5; font-size: 16px;"><strong>4 : </strong> '.esc_html__( 'Import Slides ( Rev. Slider )', 'eis' ).'</p>
                </div>
                
            </div>


            <div style="float:left; width:100%; margin-top:20px;">
                
                <div style="float:left; width:50%; padding-right:15px; box-sizing:border-box;">
                    
                    <div style="float:left; width:100%; position:relative; height:287px;">
                        
                        <div style="float: left;width: 100%;position: absolute;height: 100%;top: 0px; left: 0px; background-color:#d074a0;">

                            <div style=" width: 100%;height: 100%;display: table;text-align: center;">
                                <div style="display: table-cell; vertical-align: middle;">
                                    <a style="text-decoration:none; margin:0px; padding:0px;" target="_blank" href="'.$planet_welcome_documentation_link.'/installation/"><h3 style="color:#fff; margin:0px; padding;0px; display: inline-block; border-bottom:2px solid #fff;">'.esc_html__( 'Installation', 'eis' ).'</h3></a>
                                </div>
                            </div>

                        </div>
                    </div>

                </div>

                <div style="float:left; width:50%; padding-left:15px; box-sizing:border-box;">
                    
                    <div style="float:left; width:100%; position:relative; height:287px;">
                        
                        <div style="float: left;width: 100%;position: absolute;height: 100%;top: 0px; left: 0px; background: '.$planet_welcome_color_1.'; background: -moz-linear-gradient(45deg, '.$planet_welcome_color_1.' 0%, '.$planet_welcome_color_2.' 100%); background: -webkit-linear-gradient(45deg, '.$planet_welcome_color_1.' 0%,'.$planet_welcome_color_2.' 100%); background: linear-gradient(45deg, '.$planet_welcome_color_1.' 0%,'.$planet_welcome_color_2.' 100%);">

                            <div style=" width: 100%;height: 100%;display: table;text-align: center;">
                                <div style="display: table-cell; vertical-align: middle;">
                                    <a style="text-decoration:none; margin:0px; padding:0px;" target="_blank" href="'.$planet_welcome_documentation_link.'"><h3 style="color:#fff; margin:0px; padding;0px; display: inline-block; border-bottom:2px solid #fff;">'.esc_html__( 'Theme Documentation', 'eis' ).'</h3></a>
                                </div>
                            </div>

                        </div>
                    </div>

                </div>

            </div>

        </div>

        <div style="float:left; width:100%;">  
            <p style="margin-top:60px; line-height: 1.5; font-size: 16px; color: #777;">'.esc_html__( 'Thank you for choosing', 'eis' ).' '.$planet_welcome_title.' Theme,<br>'.esc_html__( 'Planet Themes Team', 'eis' ).'</p>
        </div>

    </div>';

}
//END create welcome page on activation




function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328330&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        